@@ -1,6 +1,6 @@
 "dataquality"
 
-__version__ = "v0.8.6"
+__version__ = "v0.8.7"
 
 import os
 
@@ -30,6 +30,7 @@ from dataquality.core.log import (
     log_data_sample,
     log_data_samples,
     log_dataset,
+    log_image_dataset,
     log_model_outputs,
     set_epoch,
     set_epoch_and_split,
@@ -119,6 +120,7 @@ __all__ = [
     "set_console_url",
     "log_data_sample",
     "log_dataset",
+    "log_image_dataset",
     "get_dq_log_file",
     "build_run_report",
     "register_run_report",
