@@ -29,6 +29,7 @@ from dataquality.utils.thread_pool import ThreadPoolManager
 from dataquality.utils.vaex import (
     _join_in_out_frames,
     concat_hdf5_files,
+    create_data_embs,
     filter_df,
     validate_unique_ids,
 )
@@ -40,6 +41,13 @@ MetaType = TypeVar("MetaType", bound=Dict[str, Union[str, float, int]])
 ITER_CHUNK_SIZE = 100_000
 
 
+# Vaex issue https://github.com/vaexio/vaex/issues/2282
+try:
+    vaex.progress.bar("vaex")
+except NameError:
+    vaex.progress._progressbar_registry.registry["vaex"] = vaex.progress.simple
+
+
 class BaseGalileoDataLogger(BaseGalileoLogger):
     MAX_META_COLS = 25  # Limit the number of metadata attrs a user can log
     MAX_STR_LEN = 1000  # Max characters in a string metadata attribute
@@ -117,10 +125,16 @@ class BaseGalileoDataLogger(BaseGalileoLogger):
             raise GalileoException(exc)
         self.logger_config.logged_input_ids[split].update(ids)
 
+    def add_ids_to_split(self, ids: List) -> None:
+        if self.split:
+            self.logger_config.idx_to_id_map[str(self.split)].extend(ids)
+
     def log(self) -> None:
         """Writes input data to disk in .galileo/logs
 
-        If input data already exist, append new data to existing input file
+        If input data already exist, append new data to existing input file.
+        If the dataset is very large this function will be called multiple
+        times for a given split.
         """
         self.validate()
         write_input_dir = self.write_output_dir()
@@ -129,7 +143,9 @@ class BaseGalileoDataLogger(BaseGalileoLogger):
 
         df = self._get_input_df()
         self.validate_data_size(df)
-        self.validate_ids_for_split(df["id"].tolist())
+        ids = df["id"].tolist()
+        self.validate_ids_for_split(ids)
+        self.add_ids_to_split(ids)
 
         file_path = self.input_data_file()
         if self.log_export_progress:
@@ -141,11 +157,16 @@ class BaseGalileoDataLogger(BaseGalileoLogger):
         df.close()
         self.logger_config.input_data_logged[str(self.split)] += 1
 
-    def upload(self, last_epoch: Optional[int] = None) -> None:
+    def upload(
+        self, last_epoch: Optional[int] = None, create_data_embs: bool = False
+    ) -> None:
         """
         Iterates through all of each splits children folders [data/emb/prob] for each
         inference name / epoch, concatenates all of the files with vaex, and uploads
         them to a single file in minio
+
+        If create_data_embs is True, this will also run an off the shelf transformer
+        and upload those text embeddings alongside the models finetuned embeddings
         """
         ThreadPoolManager.wait_for_threads()
         self.check_for_logging_failures()
@@ -172,12 +193,31 @@ class BaseGalileoDataLogger(BaseGalileoLogger):
             in_frame_split = vaex.open(f"{in_frame_path}/*.arrow")
             in_frame_split = self.convert_large_string(in_frame_split)
             self.upload_split(
-                object_store, in_frame_split, split, split_loc, last_epoch
+                object_store,
+                in_frame_split,
+                split,
+                split_loc,
+                last_epoch,
+                create_data_embs,
             )
             in_frame_split.close()
             shutil.rmtree(in_frame_path)
             gc.collect()
 
+    @classmethod
+    def create_and_upload_data_embs(
+        cls, df: DataFrame, split: str, epoch_or_inf: str
+    ) -> None:
+        """Uploads off the shelf data embeddings for a split"""
+        object_store = ObjectStore()
+        df_copy = df.copy()
+        # Create
+        data_embs = create_data_embs(df_copy)
+        proj_run_split = f"{config.current_project_id}/{config.current_run_id}/{split}"
+        minio_file = f"{proj_run_split}/{epoch_or_inf}/data_emb/data_emb.hdf5"
+        # And upload
+        object_store.create_project_run_object_from_df(data_embs, minio_file)
+
     def convert_large_string(self, df: DataFrame) -> DataFrame:
         """Cast regular string to large_string for the text column
 
@@ -201,6 +241,7 @@ class BaseGalileoDataLogger(BaseGalileoLogger):
         split: str,
         split_loc: str,
         last_epoch: Optional[int] = None,
+        create_data_embs: bool = False,
     ) -> None:
         # If set, last_epoch will only let you upload to and including the provided
         # epoch value, nothing more.
@@ -213,6 +254,8 @@ class BaseGalileoDataLogger(BaseGalileoLogger):
         last_epoch = last_epoch + 1 if last_epoch else last_epoch
         epochs_or_infs = epochs_or_infs[:last_epoch]
 
+        largest_epoch = epochs_or_infs[-1]
+
         # For each inference name or epoch of the given split
         for epoch_or_inf in tqdm(
             epochs_or_infs,
@@ -232,6 +275,12 @@ class BaseGalileoDataLogger(BaseGalileoLogger):
                         GalileoWarning,
                     )
                     continue
+            if create_data_embs and (
+                split == Split.inference or epoch_or_inf == largest_epoch
+            ):
+                name = f"{split}/{epoch_or_inf}" if split == Split.inference else split
+                print(f"Creating and uploading data embeddings for {name}")
+                cls.create_and_upload_data_embs(input_batch, split, epoch_or_inf)
 
             dir_name = f"{split_loc}/{epoch_or_inf}"
             in_out_frames = cls.create_in_out_frames(
@@ -257,7 +306,7 @@ class BaseGalileoDataLogger(BaseGalileoLogger):
         :param in_frame: the input dataframe
         :param dir_name: The directory of all of the output hdf5 files
         :param prob_only: If we are only uploading probability data. We only upload
-            probability data for all epochs expect the last one (we dont use cross-epoch
+            probability data for all epochs except the last one (we dont use cross-epoch
             embeddings currently, so we dont log them)
         :param split: The split we are logging for
         :param epoch_or_inf: The epoch or inference name we are logging for
@@ -374,6 +423,10 @@ class BaseGalileoDataLogger(BaseGalileoLogger):
 
     def validate(self) -> None:
         self.set_split_epoch()
+        if self.split != Split.inference:
+            assert (
+                self.logger_config.labels is not None
+            ), "You must set labels before logging input data"
 
     @classmethod
     @abstractmethod
