@@ -151,7 +151,7 @@ class TextClassificationDataLogger(BaseGalileoDataLogger):
         self.split = split
         self.labels = [str(i) for i in labels] if labels is not None else []
         self.inference_name = inference_name
-        self.meta = meta or {}
+        self.meta: Union[MetasType, Dict] = meta or {}
         self.log()
 
     def log_data_sample(
@@ -264,10 +264,29 @@ class TextClassificationDataLogger(BaseGalileoDataLogger):
         HuggingFace datasets can be sliced, returning a dict that is in the correct
         format to log directly.
         """
+
+        parse_label = lambda x: x  # noqa: E731
+        # If label is integer, convert to string #
+
+        if isinstance(dataset[0].get(label), int):
+            try:
+                parse_label = lambda x: dataset.features[label].int2str(x)  # noqa: E731
+            except Exception:
+                # TODO: Simplify this logic with mapping the int label to string ticket
+                raise GalileoException(
+                    "Your dataset does not have label names. Please include them"
+                )
+
+        assert dataset[0].get(id) is not None, GalileoException(
+            f"id ({id}) field must be present in dataset"
+        )
+
         for i in range(0, len(dataset), batch_size):
             chunk = dataset[i : i + batch_size]
             data = dict(
-                text=chunk[text], id=chunk[id], label=chunk[label] if label else None
+                text=chunk[text],
+                id=chunk[id],
+                label=parse_label(chunk[label]) if label else None,
             )
             chunk_meta = {col: chunk[col] for col in meta}
             self._log_dict(data, chunk_meta, split, inference_name)
@@ -327,7 +346,7 @@ class TextClassificationDataLogger(BaseGalileoDataLogger):
         self.texts = df["text"].tolist()
         self.ids = df["id"].tolist()
         # Inference case
-        if "label" in df.columns:
+        if "label" in df:
             self.labels = df["label"].tolist()
         for meta_col in meta:
             self.meta[str(meta_col)] = df[meta_col].tolist()
@@ -349,14 +368,22 @@ class TextClassificationDataLogger(BaseGalileoDataLogger):
         * Text and Labels must be the same length
         * If ids exist, it must be the same length as text/labels
         :return: None
+
+        If the user logged labels as ints, convert them to the string labels.
+        In the next optimization, we will support the API having int labels, but for
+        now it expects string labels. When we make that change, we will do the opposite
+        and always convert to the int index of the labels.
         """
         super().validate()
-
         label_len = len(self.labels)
         text_len = len(self.texts)
         id_len = len(self.ids)
 
-        self.texts = list(self._convert_tensor_ndarray(self.texts))
+        set_labels_are_ints = self.logger_config.int_labels
+        if label_len and isinstance(self.labels[0], int) and not set_labels_are_ints:
+            self.labels = [self.logger_config.labels[lbl] for lbl in self.labels]
+        if not isinstance(self.texts, list):
+            self.texts = list(self._convert_tensor_ndarray(self.texts))
         clean_labels = self._convert_tensor_ndarray(self.labels, attr="Labels")
         # If the dtype if object, we have a ragged nested sequence, so we need to
         # iterate list by list converting to strings
@@ -422,7 +449,7 @@ class TextClassificationDataLogger(BaseGalileoDataLogger):
 
     @classmethod
     def split_dataframe(
-        cls, df: DataFrame, prob_only: bool
+        cls, df: DataFrame, prob_only: bool, split: str
     ) -> Tuple[DataFrame, DataFrame, DataFrame]:
         """Splits the singular dataframe into its 3 components
 
