@@ -270,6 +270,7 @@ def get_dataframe(
     tagging_schema: Optional[TaggingSchema] = None,
     filter: Union[FilterParams, Dict] = None,
     as_pandas: bool = True,
+    include_data_embs: bool = False,
 ) -> Union[pd.DataFrame, DataFrame]:
     """Gets the dataframe for a run/split
 
@@ -278,9 +279,9 @@ def get_dataframe(
 
     Special note for NER. By default, the data will be downloaded at a sample level
     (1 row per sample text), with spans for each sample in a `spans` column in a
-    spacy-compatible JSON format. If include_emb is True, the data will be expanded
-    into span level (1 row per span, with sample text repeated for each span row), in
-    order to join the span-level embeddings
+    spacy-compatible JSON format. If include_embs or include_probs is True,
+    the data will be expanded into span level (1 row per span, with sample text repeated
+    for each span row), in order to join the span-level embeddings/probs
 
     :param project_name: The project name
     :param run_name: The run name
@@ -303,6 +304,7 @@ def get_dataframe(
         and vaex will memory map the data. If any columns returned are multi-dimensional
         (embeddings, probabilities etc), vaex will always be returned, because pandas
         cannot support multi-dimensional columns. Default True
+    :param include_data_embs: Whether to include the off the shelf data embeddings
     """
     split = conform_split(split)
     project_id, run_id = api_client._get_project_run_id(project_name, run_name)
@@ -331,6 +333,7 @@ def get_dataframe(
         include_token_indices,
         hf_format,
         as_pandas,
+        include_data_embs,
     )
 
 
@@ -346,6 +349,7 @@ def get_edited_dataframe(
     hf_format: bool = False,
     tagging_schema: Optional[TaggingSchema] = None,
     as_pandas: bool = True,
+    include_data_embs: bool = False,
 ) -> Union[pd.DataFrame, DataFrame]:
     """Gets the edited dataframe for a run/split
 
@@ -354,9 +358,9 @@ def get_edited_dataframe(
 
     Special note for NER. By default, the data will be downloaded at a sample level
     (1 row per sample text), with spans for each sample in a `spans` column in a
-    spacy-compatible JSON format. If include_emb is True, the data will be expanded
-    into span level (1 row per span, with sample text repeated for each span row), in
-    order to join the span-level embeddings
+    spacy-compatible JSON format. If include_embs or include_probs is True,
+    the data will be expanded into span level (1 row per span, with sample text repeated
+    for each span row), in order to join the span-level embeddings/probs
 
     :param project_name: The project name
     :param run_name: The run name
@@ -377,6 +381,7 @@ def get_edited_dataframe(
         and vaex will memory map the data. If any columns returned are multi-dimensional
         (embeddings, probabilities etc), vaex will always be returned, because pandas
         cannot support multi-dimensional columns. Default True
+    :param include_data_embs: Whether to include the off the shelf data embeddings
     """
     split = conform_split(split)
     project_id, run_id = api_client._get_project_run_id(project_name, run_name)
@@ -405,6 +410,7 @@ def get_edited_dataframe(
         include_token_indices,
         hf_format,
         as_pandas,
+        include_data_embs,
     )
 
 
@@ -421,20 +427,25 @@ def _process_exported_dataframe(
     include_token_indices: bool = False,
     hf_format: bool = False,
     as_pandas: bool = True,
+    include_data_embs: bool = False,
 ) -> Union[pd.DataFrame, DataFrame]:
     """Process dataframe after export of run or edits.
 
     See `get_dataframe` and `get_edited_dataframe` for details"""
     split = conform_split(split)
     # See docstring. In this case, we need span-level data
-    # You can't attach embeddings to the huggingface data, since the HF format is
+    # You can't attach embeddings/probs to the huggingface data, since the HF format is
     # sample level, and the embeddings are span level
-    if include_embs and task_type == TaskType.text_ner and not hf_format:
+    embs = include_embs or include_data_embs
+    if (embs or include_probs) and task_type == TaskType.text_ner and not hf_format:
         # In NER, the `probabilities` contains the span level data
         span_df = get_probabilities(project_name, run_name, split, inference_name)
+        keep_cols = [i for i in span_df.get_column_names() if "prob" not in i]
+        span_df = span_df[keep_cols]
         # These are the token (not char) indices, lets make that clear
         span_df.rename("span_start", "span_token_start")
         span_df.rename("span_end", "span_token_end")
+
         for i in data_df.get_column_names():
             if i != "sample_id":
                 data_df.rename(i, f"sample_{i}")
@@ -462,18 +473,27 @@ def _process_exported_dataframe(
         else:
             emb_df = get_embeddings(project_name, run_name, split, inference_name)
             data_df = data_df.join(emb_df, on="id")
-    if include_probs:
-        if task_type == task_type.text_ner:
+    if include_data_embs:
+        # Embeddings are span level, but huggingface is sample level, so can't combine
+        if hf_format:
             warnings.warn(
-                "Probabilities are not available for NER runs, ignoring", GalileoWarning
+                "Embeddings are not available in HF format, ignoring", GalileoWarning
             )
-        elif hf_format:
+        else:
+            emb_df = get_data_embeddings(
+                project_name, run_name, split, inference_name
+            ).copy()
+            emb_df.rename("emb", "data_emb")
+            data_df = data_df.join(emb_df, on="id")
+    if include_probs:
+        if hf_format:
             warnings.warn(
                 "Probabilities are not available in HF format, ignoring", GalileoWarning
             )
         else:
             prob_df = get_probabilities(project_name, run_name, split, inference_name)
-            prob_cols = prob_df.get_column_names(regex="prob*") + ["id"]
+            # Includes `prob` for TC, `prob_#` for MLTC, and `conf/loss_prob` for NER
+            prob_cols = prob_df.get_column_names(regex=r".*prob*") + ["id"]
             data_df = data_df.join(prob_df[prob_cols], on="id")
             data_df = _rename_prob_cols(data_df, tasks)
     if include_token_indices:
@@ -543,6 +563,31 @@ def get_embeddings(
     )
 
 
+def get_data_embeddings(
+    project_name: str,
+    run_name: str,
+    split: Split,
+    inference_name: str = "",
+) -> DataFrame:
+    """Downloads the data (off the shelf) embeddings for a run/split
+
+    An hdf5 file will be downloaded to local and a Vaex dataframe will be returned
+
+    :param project_name: The project name
+    :param run_name: The run name
+    :param split: The split (training/test/validation/inference)
+    :param inference_name: Required if split is inference
+    """
+    split = conform_split(split)
+    return _get_hdf5_file_for_epoch(
+        project_name,
+        run_name,
+        split,
+        "data_emb/data_emb.hdf5",
+        inference_name,
+    )
+
+
 def get_probabilities(
     project_name: str,
     run_name: str,
